@@ -2,8 +2,8 @@
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006-2008 Vlad Vasiliev
- * Copyright (C) 2006-2008 Pavel Fialko
+ * Copyright (C) 2006-2009 Vlad Vasiliev
+ * Copyright (C) 2006-2009 Pavel Fialko
  * Copyright (C) 2008      Andrew Olmsted
  * 	for the code
  *
@@ -59,10 +59,6 @@
     #include <X11/extensions/Xcomposite.h>
     #include <X11/extensions/Xdamage.h>
     #include <X11/extensions/Xrender.h>
-#ifdef ENABLE_GPS
-    #include <location/location-gps-device.h>
-    #include <location/location-gpsd-control.h>
-#endif
 
 #elif  NONMAEMO
     #include <hildon/hildon-banner.h>
@@ -73,6 +69,11 @@
 #else
     #include <hildon-widgets/hildon-banner.h>
 #endif
+#ifdef ENABLE_GPS
+    #include <location/location-gps-device.h>
+    #include <location/location-gpsd-control.h>
+#endif
+
 #ifdef CLUTTER
     #include <clutter/clutter.h>
     #include <clutter-gtk/gtk-clutter-embed.h>
@@ -88,18 +89,28 @@
 #include <libxml/xpath.h>
 #include <libxml/xpathInternals.h>
 /*******************************************************************************/
+
 #define _(String) dgettext (GETTEXT_PACKAGE, String)
 #define Max_count_weather_day	10
 #define DATABASEPATH		"/usr/share/omweather/db/"
-#define SOURCESPATH		"/usr/share/omweather/sources/"
+#define SOURCESPATH		    "/usr/share/omweather/sources/"
+#define STYLEPATH           "/usr/share/omweather/"
 #define COPYRIGHT_ICONS		"/usr/share/omweather/copyright_icons/"
 #define COUNTRIESFILE		"countries.list"
-#define REGIONSFILE		"regions.list"
+#define REGIONSFILE		    "regions.list"
 #define LOCATIONSFILE		"locations.list"
-#define ICONS_PATH		"/usr/share/omweather/icons/"
+#define ICONS_PATH	    	"/usr/share/omweather/icons/"
 #define BUTTON_ICONS		"/usr/share/omweather/button_icons/"
-#define START_FUNCTION		fprintf(stderr,"\n>>>>>>>>>Start %s()\n", __PRETTY_FUNCTION__);
+
+#define START_FUNCTION        fprintf(stderr,"\n>>>>>>>>>Start %s()\n", __PRETTY_FUNCTION__);
 #define END_FUNCTION		fprintf(stderr,"\n>>>>>>>>>End %s()\n", __PRETTY_FUNCTION__);
+
+/*
+extern void write_log(char *string);
+#define START_FUNCTION          FILE *file; file=fopen("/tmp/omw.log","a+"); fprintf(file,"\n>>>>>>>>>Start %s()\n", __PRETTY_FUNCTION__);fflush(file);fclose(file);
+#define DEBUG_FUNCTION(string)  write_log(string)
+#define END_FUNCTION          FILE *fileend; fileend=fopen("/tmp/omw.log","a+"); fprintf(fileend,"\n>>>>>>>>>End %s()\n", __PRETTY_FUNCTION__);fflush(fileend);fclose(fileend);
+*/
 #define OMWEATHER_ADD_STATION		1000
 #define OMWEATHER_SEARCH_STATION	1001
 #define OMWEATHER_CLOSE_STATION_WINDOW	1002
@@ -325,7 +336,7 @@ typedef struct SuperOH{
 /*******************************************************************************/
 typedef struct OMWeatherApplet{
     HildonProgram       *app;       /* handle to application */
-    HildonWindow        *main_view; /* handle to app's view */
+    GtkWidget           *main_view; /* handle to app's view */
     osso_context_t	*osso;
     GHashTable		*hash,
 			*sources_units;
@@ -392,9 +403,11 @@ typedef struct OMWeatherApplet{
     gint		ah;
     GSList		*tab_of_window_popup;
     GSList		*handles;
-    gboolean            fullscreen;
+    WeatherStationData  wsd;
+    GSList              *sources;
+    GSList              *clutter_objects_in_main_form;
+    GSList              *clutter_objects_in_popup_form;
 #ifdef ENABLE_GPS
-#ifdef OS2008
     guint		gps_id_connection;
     guint		gps_id_gpsdevice;
     guint		gps_run;
@@ -405,17 +418,18 @@ typedef struct OMWeatherApplet{
     gdouble		temporary_station_latitude;
     gdouble		temporary_station_longtitude;
 #endif
+#ifdef OS2009
+    gboolean    portrait_position;
 #endif
 #if defined(OS2008) || defined(DEBUGTEMP) || defined(OS2009)
     gfloat		sensor_data;
 #endif
-#ifdef USE_CONIC    
+#ifdef USE_CONIC
     ConIcConnection     *connection;
 #endif
-    WeatherStationData  wsd;
-    GSList              *sources;
-    GSList              *clutter_objects_in_main_form;
-    GSList              *clutter_objects_in_popup_form;
+#ifdef USE_DBUS
+    DBusConnection      *dbus_conn;
+#endif
 #ifdef CLUTTER
     ClutterScript       *clutter_script; /* Maybe it need be deleting */
 #endif
