@@ -1,8 +1,8 @@
 /* vim: set sw=4 ts=4 et: */
 /* This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006-2008 Vlad Vasiliev
- * Copyright (C) 2006-2008 Pavel Fialko
+ * Copyright (C) 2006-2009 Vlad Vasiliev
+ * Copyright (C) 2006-2009 Pavel Fialko
  * 	for the code
  *        
  * Copyright (C) 2008 Andrew Zhilin
@@ -34,13 +34,19 @@
 /*******************************************************************************/
 void initial_gps_connect(void);
 void deinitial_gps_connect(void);
+void initial_gps_control(void);
+void deinitial_gps_control(void);
 void delete_all_gps_stations(void);
 void get_nearest_station( double lat, double lon, Station *result);
 /*******************************************************************************/
 extern int parse_region_string(const char *string, Region_item *result);
 extern gdouble calculate_distance(gdouble lat1, gdouble lon1, gdouble lat2, gdouble lon2);
-extern	WeatherSource	weather_sources[];
+extern WeatherSource weather_sources[];
 extern GtkListStore* create_items_list(const char *path, const char *filename,
-				long start, long end, long *items_number);
+                                       long start, long end, long *items_number);
+extern sqlite3* open_database(const char *path, const char *filename);
+extern GtkListStore* create_regions_list(sqlite3 *database, int country_id, int *region_count);
+extern GtkListStore* create_stations_list(sqlite3 *database, gint region_id);
+extern void close_database(sqlite3 *database);
 /*******************************************************************************/
 #endif
