@@ -2,8 +2,8 @@
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006 Vlad Vasiliev
- * Copyright (C) 2006 Pavel Fialko
+ * Copyright (C) 2006-2009 Vlad Vasiliev
+ * Copyright (C) 2006-2009 Pavel Fialko
  * 	for the code
  *        
  * Copyright (C) 2008 Andrew Zhilin
@@ -62,20 +62,20 @@ int calculate_offset_of_day(int count_day);
 void add_change_day_part_event(GSList *day, guint year, guint month);
 time_t get_day_part_begin_time(GSList *day, guint year, const gchar *day_part);
 void add_wind_text(GSList *day, gchar *buffer, gboolean is_day);
+void view_popup_menu (GtkWidget *treeview, GdkEventButton *event, gpointer userdata);
 void create_current_temperature_text(GSList *day, gchar *buffer, gboolean valid,
 							const gchar *day_name);
 void create_day_temperature_text(GSList *day, gchar *buffer, gboolean valid,
 						gboolean for_combination_mode);
-						
+#if defined OS2008 || defined OS2009 || defined APPLICATION || defined NONMAEMO
+void omweather_destroy(GtkObject *widget);
+#endif
+
 gboolean expose_main_window1(GtkWidget *widget, GdkEventExpose *event);
 #ifdef OS2008
 GtkWidget*
 settings_menu(HildonDesktopHomeItem *home_item, GtkWindow *parent);
 #endif
-#ifdef OS2009
-gboolean
-omweather_init_OS2009(GtkWidget *applet);
-#endif
 /*******************************************************************************/
 extern void swap_temperature(int *hi, int *low);
 extern float c2f(float temp);
@@ -107,9 +107,11 @@ extern gint parse_weather_com_xml_hour(const gchar *station_id, weather_com_pars
 extern gint parse_rp5_ru_xml(const gchar *station_id, weather_com_parser *parser, WeatherStationData *wsd);
 extern time_t last_update_time(GSList *object);
 extern float convert_wind_units(int to, float value);
-#if defined(OS2008) || defined(OS2009)
+#if defined (ENABLE_GPS)
+extern void initial_gps_control(void);
 extern void initial_gps_connect(void);
 extern void deinitial_gps_connect(void);
+extern void deinitial_gps_control(void);
 extern gboolean expose_parent(GtkWidget *widget, GdkEventExpose *event);
 #endif
 extern void weather_window_popup(GtkWidget *widget, GdkEvent *event, gpointer user_data);
@@ -127,17 +129,20 @@ gboolean top_widget_expose(GtkWidget *widget, GdkEventExpose *event);
 #endif
 extern GtkWidget* create_time_updates_widget(GSList *current, gboolean change_color);
 #endif
-extern GtkWidget* create_toolbar_box(gpointer exit_function, gpointer arg_exit_function);
+extern GtkWidget *create_toolbar_box(gpointer exit_function, GtkWidget *window, gboolean fullscreen_button);
 extern void free_list_time_event(void);
 extern void event_add(time_t time_value, short int type_event);
 extern void destroy_popup_window(void);
 extern float mb2mm(float pressure);
 extern GtkWidget *create_icon_widget(GdkPixbuf *icon_buffer, const char *icon_path, int icon_size, GSList **objects_list);
+#ifdef USE_DBUS
+extern void weather_deinitialize_dbus(void);
+#endif
 #ifdef CLUTTER
 void free_clutter_objects_list(GSList **clutter_objects);
 #endif
 #if defined(OS2009)
-    init_portrait(main_widget);
+void init_portrait(main_widget);
 #endif
 extern gboolean show_animation(GSList *clutter_objects);
 /*******************************************************************************/
