@@ -1,8 +1,8 @@
 /* vim: set sw=4 ts=4 et: */
 /* This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006 Vlad Vasiliev
- * Copyright (C) 2006 Pavel Fialko
+ * Copyright (C) 2006-2009 Vlad Vasiliev
+ * Copyright (C) 2006-2009 Pavel Fialko
  * 	for the code
  *
  * Copyright (C) 2008 Andrew Zhilin
@@ -46,10 +46,9 @@ dbus_callback(const gchar *interface, const gchar *method, GArray *arguments,
 /*******************************************************************************/
 int
 main(int argc, char *argv[]){
-    HildonProgram   *OMWeather = NULL;
     osso_context_t  *osso_context;
     osso_return_t   ret;
-
+    GtkWidget* window;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
@@ -66,9 +65,9 @@ main(int argc, char *argv[]){
     }
     gtk_init(&argc, &argv);
 
-    OMWeather = create_omweather();
-    app->main_view = OMWeather;
-    if(app->main_view){
+    window = create_omweather();
+    if(window){
+          app->main_view =  window;
           /* Create the hildon application and setup the title */
           app->app = HILDON_PROGRAM ( hildon_program_get_instance () );
           g_set_application_name (PACKAGE);
@@ -77,12 +76,20 @@ main(int argc, char *argv[]){
               fprintf (stderr, "osso_rpc_set_default_cb_f failed: %d.\n", ret);
               return 2;
           }
-
-          hildon_program_add_window( app->app, app->main_view);
+          hildon_program_add_window(app->app, HILDON_WINDOW(app->main_view));
           app->osso = osso_context;
-          gtk_widget_show_all(app->main_view);
+          #if defined OS2009
+             check_device_position(app->dbus_conn);
+             if (app->portrait_position){
+                fprintf(stderr,"Portrait Position\n ");
+                init_portrait(app->main_view);
+             }else{
+                fprintf(stderr,"Landscape Position\n ");
+                init_landscape(app->main_view);
+             }
+          #endif
+          gtk_widget_show_all(GTK_WIDGET(app->main_view));
           gtk_main();
-          gtk_widget_destroy(app->main_view);
     }
     osso_deinitialize(osso_context);
 #ifdef DEBUGFUNCTIONCALL
@@ -99,31 +106,24 @@ main_window_button_key_press_cb(GtkWidget *widget, GdkEventKey *event,
     START_FUNCTION;
 #endif
     if(event->keyval == GDK_F6){
-    /* The "Full screen" hardware key has been pressed */
-        if(app->fullscreen == GDK_WINDOW_STATE_FULLSCREEN)
-            gtk_window_unfullscreen (GTK_WINDOW(user_data));
-        else
-            gtk_window_fullscreen (GTK_WINDOW(user_data));
+        /* The "Full screen" hardware key has been pressed */
+        change_state_window(user_data);
     }
+#ifdef OS2009
+    if(event->keyval == GDK_F5){
+      if (app->portrait_position)
+           init_landscape(widget);
+      else
+           init_portrait(widget);
+    }
+#endif
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
     return FALSE;
 }
 /*******************************************************************************/
-gboolean
-main_window_state_event_cb(GtkWidget *widget, GdkEventWindowState *event,
-				gpointer user_data){
-#ifdef DEBUGFUNCTIONCALL
-    START_FUNCTION;
-#endif
-    app->fullscreen = (event->new_window_state & GDK_WINDOW_STATE_FULLSCREEN);
-    return FALSE;
-}
-
-
-/*******************************************************************************/
-HildonWindow*
+GtkWidget*
 create_omweather(void){
     GtkWidget *main_widget = NULL;
 
@@ -147,7 +147,7 @@ create_omweather(void){
 #endif
 
 /* Set background image */
-    pixbuf = gdk_pixbuf_new_from_file ("/usr/share/omweather/images/crime.png",&error);
+    pixbuf = gdk_pixbuf_new_from_file ("/usr/share/omweather/images/background.png",&error);
     if (error != NULL) {
         if (error->domain == GDK_PIXBUF_ERROR) {
             g_print ("Pixbuf Related Error:\n");
@@ -161,16 +161,13 @@ create_omweather(void){
        style = gtk_style_new ();
        style->bg_pixmap[0] = background;
        gtk_widget_set_style (GTK_WIDGET(main_widget), GTK_STYLE(style));
+       g_object_unref(pixbuf);
     }
-    
+
     gtk_window_set_title(GTK_WINDOW(main_widget), PACKAGE);
     gtk_window_set_default_size(GTK_WINDOW(main_widget), 800, 480);
-    
-#if defined OS2009
-//    init_portrait(main_widget);
-#endif
 
-    if(!omweather_init_OS2009(main_widget))
+    if(!omweather_init_OS2009(GTK_WIDGET(main_widget)))
         return NULL;
 /* signals */
     g_signal_connect((gpointer)main_widget, "destroy_event",
@@ -182,13 +179,12 @@ create_omweather(void){
     g_signal_connect (main_widget, "key_press_event",
                       G_CALLBACK (main_window_button_key_press_cb),
                       main_widget);
-/* For fullscreen/ unfullscreen mode */
-    g_signal_connect (main_widget, "window_state_event",
-                      G_CALLBACK (main_window_state_event_cb),
-                      NULL);
 
     gtk_widget_modify_bg(main_widget, GTK_STATE_NORMAL,
 			    &app->config->background_color);
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
 
     return main_widget;
 }/*******************************************************************************/
